searchNodes=[{"doc":"Implements the CLDR locale display name algorithm to format a t:Cldr.LanguageTag structs for presentation uses.","ref":"Cldr.LocaleDisplay.html","title":"Cldr.LocaleDisplay","type":"module"},{"doc":"Returns a localised display name for a locale. UI applications often have a requirement to present locale choices to an end user. This function takes a t.Cldr.LanguageTag and using the CLDR locale display name algorithm produces a string suitable for presentation. Arguments language_tag is any t:Cldr.LanguageTag or a binary locale name. options is a keyword list of options. Options :compound_locale is a boolean indicating if the combination of language, script and territory should be used to resolve a language name. The default is true . :prefer signals the preferred name for a subtag when there are alternatives. The default is :default . Few subtags provide alternative renderings. Some of the alternative preferences are :short , :long , :menu and :variant . :locale is a t:Cldr.LanguageTag or any valid locale name returned by Cldr.known_locale_names/1 . :backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . Returns {:ok, string} representating a name suitable for presentation purposes or {:error, {exception, reason}} Examples iex&gt; Cldr.LocaleDisplay . display_name &quot;en&quot; { :ok , &quot;English&quot; } iex&gt; Cldr.LocaleDisplay . display_name &quot;en-US&quot; { :ok , &quot;American English&quot; } iex&gt; Cldr.LocaleDisplay . display_name &quot;en-US&quot; , compound_locale : false { :ok , &quot;English (United States)&quot; } iex&gt; Cldr.LocaleDisplay . display_name &quot;en-US-u-ca-gregory-cu-aud&quot; { :ok , &quot;American English (Gregorian Calendar, Currency: A$)&quot; } iex&gt; Cldr.LocaleDisplay . display_name &quot;en-US-u-ca-gregory-cu-aud&quot; , locale : &quot;fr&quot; { :ok , &quot;anglais américain (calendrier grégorien, devise : A$)&quot; } iex&gt; Cldr.LocaleDisplay . display_name &quot;nl-BE&quot; { :ok , &quot;Flemish&quot; } iex&gt; Cldr.LocaleDisplay . display_name &quot;nl-BE&quot; , compound_locale : false { :ok , &quot;Dutch (Belgium)&quot; }","ref":"Cldr.LocaleDisplay.html#display_name/2","title":"Cldr.LocaleDisplay.display_name/2","type":"function"},{"doc":"Returns a localised display name for a locale. UI applications often have a requirement to present locale choices to an end user. This function takes a t.Cldr.LanguageTag and using the CLDR locale display name algorithm produces a string suitable for presentation. Arguments language_tag is any t:Cldr.LanguageTag or a binary locale name. options is a keyword list of options. Options :compound_locale is a boolean indicating if the combination of language, script and territory should be used to resolve a language name. The default is true . :prefer signals the preferred name for a subtag when there are alternatives. The default is :default . Few subtags provide alternative renderings. Some of the alternative preferences are :short , :long , :menu and :variant . :locale is a t:Cldr.LanguageTag or any valid locale name returned by Cldr.known_locale_names/1 . :backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . Returns a string representation of the language tag suitable for presentation purposes or raises an exception. Examples iex&gt; Cldr.LocaleDisplay . display_name! &quot;en&quot; &quot;English&quot; iex&gt; Cldr.LocaleDisplay . display_name! &quot;en-US&quot; &quot;American English&quot; iex&gt; Cldr.LocaleDisplay . display_name! &quot;en-US&quot; , compound_locale : false &quot;English (United States)&quot; iex&gt; Cldr.LocaleDisplay . display_name! &quot;en-US-u-ca-gregory-cu-aud&quot; &quot;American English (Gregorian Calendar, Currency: A$)&quot; iex&gt; Cldr.LocaleDisplay . display_name! &quot;en-US-u-ca-gregory-cu-aud&quot; , locale : &quot;fr&quot; &quot;anglais américain (calendrier grégorien, devise : A$)&quot;","ref":"Cldr.LocaleDisplay.html#display_name!/2","title":"Cldr.LocaleDisplay.display_name!/2","type":"function"},{"doc":"","ref":"Cldr.LocaleDisplay.html#t:display_options/0","title":"Cldr.LocaleDisplay.display_options/0","type":"type"},{"doc":"","ref":"Cldr.LocaleDisplay.Extension.html","title":"Cldr.LocaleDisplay.Extension","type":"module"},{"doc":"","ref":"Cldr.LocaleDisplay.Extension.html#display_name/2","title":"Cldr.LocaleDisplay.Extension.display_name/2","type":"function"},{"doc":"","ref":"Cldr.LocaleDisplay.PrivateUse.html","title":"Cldr.LocaleDisplay.PrivateUse","type":"module"},{"doc":"","ref":"Cldr.LocaleDisplay.PrivateUse.html#display_name/2","title":"Cldr.LocaleDisplay.PrivateUse.display_name/2","type":"function"},{"doc":"","ref":"Cldr.LocaleDisplay.T.html","title":"Cldr.LocaleDisplay.T","type":"module"},{"doc":"","ref":"Cldr.LocaleDisplay.T.html#display_name/2","title":"Cldr.LocaleDisplay.T.display_name/2","type":"function"},{"doc":"","ref":"Cldr.LocaleDisplay.T.html#format_key_value/6","title":"Cldr.LocaleDisplay.T.format_key_value/6","type":"function"},{"doc":"","ref":"Cldr.LocaleDisplay.U.html","title":"Cldr.LocaleDisplay.U","type":"module"},{"doc":"","ref":"Cldr.LocaleDisplay.U.html#display_name/2","title":"Cldr.LocaleDisplay.U.display_name/2","type":"function"},{"doc":"","ref":"Cldr.LocaleDisplay.U.html#format_key_value/6","title":"Cldr.LocaleDisplay.U.format_key_value/6","type":"function"},{"doc":"","ref":"Cldr.LocaleDisplay.U.html#get_currency/2","title":"Cldr.LocaleDisplay.U.get_currency/2","type":"function"},{"doc":"","ref":"Cldr.LocaleDisplay.U.html#get_timezone/2","title":"Cldr.LocaleDisplay.U.get_timezone/2","type":"function"},{"doc":"Presents language tags in a presentation format suitable for UI applications. It implements the CLDR locale display name algorithm .","ref":"readme.html","title":"Cldr Locale Display","type":"extras"},{"doc":"The package can be installed by adding ex_cldr_locale_display to your list of dependencies in mix.exs : def deps do [ { :ex_cldr_locale_display , &quot;~&gt; 1.1&quot; } ] end","ref":"readme.html#installation","title":"Cldr Locale Display - Installation","type":"extras"},{"doc":"In keeping with all ex_cldr -based libraries, a backend module is required which hosts the display data used to produce locale display names. A simple example is given here. For full information on configuring a backend module, see the configuration section for ex_cldr . defmodule MyApp.Cldr do use Cldr , locales : [ &quot;en&quot; , &quot;de&quot; , &quot;th&quot; , &quot;fr&quot; , &quot;fr-CH&quot; , &quot;zh&quot; , &quot;ar&quot; ] , default_locale : &quot;en&quot; , providers : [ Cldr.Territory , Cldr.LocaleDisplay , Cldr.Currency ] end","ref":"readme.html#configuration","title":"Cldr Locale Display - Configuration","type":"extras"},{"doc":"THe follow examples require that a :default_backend be set in config.exs for the :ex_cldr configuration key. See the configuration section for ex_cldr for more information. iex&gt; Cldr.LocaleDisplay . display_name &quot;en&quot; { :ok , &quot;English&quot; } iex&gt; Cldr.LocaleDisplay . display_name &quot;en-US&quot; { :ok , &quot;American English&quot; } iex&gt; Cldr.LocaleDisplay . display_name &quot;en-US&quot; , compound_locale : false { :ok , &quot;English (United States)&quot; } iex&gt; Cldr.LocaleDisplay . display_name &quot;en-US-u-ca-gregory-cu-aud&quot; { :ok , &quot;American English (Gregorian Calendar, Currency: A$)&quot; } iex&gt; Cldr.LocaleDisplay . display_name &quot;en-US-u-ca-gregory-cu-aud&quot; , locale : &quot;fr&quot; { :ok , &quot;anglais américain (calendrier grégorien, devise : A$)&quot; } iex&gt; Cldr.LocaleDisplay . display_name &quot;nl-BE&quot; { :ok , &quot;Flemish&quot; } iex&gt; Cldr.LocaleDisplay . display_name &quot;nl-BE&quot; , compound_locale : false { :ok , &quot;Dutch (Belgium)&quot; } Rendering a list of locales in their own languages When presenting a list of locales to a user for selection it may be appropriate to present those display name in the language of the locale. The package ex_cldr_html includes a helper function for this but a simple approach is also possible. The following snippet renders the list of known locales as display names in each locales own language. It uses a backend module configuration noted above. iex&gt; MyApp.Cldr . known_locale_names ( ) ... . |&gt; Enum . map ( &amp; { &amp;1 , MyApp.Cldr.LocaleDisplay . display_name! ( &amp;1 , locale : &amp;1 , prefer : :menu ) } ) ... . |&gt; Enum . sort [ { &quot;ar&quot; , &quot;العربية&quot; } , { &quot;de&quot; , &quot;Deutsch&quot; } , { &quot;en&quot; , &quot;English&quot; } , { &quot;fr&quot; , &quot;français&quot; } , { &quot;fr-CH&quot; , &quot;français suisse&quot; } , { &quot;th&quot; , &quot;ไทย&quot; } , { &quot;zh-Hans&quot; , &quot;简体中文&quot; } , { &quot;zh-Hant&quot; , &quot;繁體中文&quot; } ] # In some cases it is preferred to not use compound # locale names. Note the different rendering for the # locale fr-CH iex&gt; MyApp.Cldr . known_locale_names ... . |&gt; Enum . map ( &amp; { &amp;1 , MyApp.Cldr.LocaleDisplay . display_name! ( &amp;1 , locale : &amp;1 , compound_locale : false , prefer : :menu ) } ) ... . |&gt; Enum . sort [ { &quot;ar&quot; , &quot;العربية&quot; } , { &quot;de&quot; , &quot;Deutsch&quot; } , { &quot;en&quot; , &quot;English&quot; } , { &quot;fr&quot; , &quot;français&quot; } , { &quot;fr-CH&quot; , &quot;français (Suisse)&quot; } , { &quot;th&quot; , &quot;ไทย&quot; } , { &quot;zh-Hans&quot; , &quot;简体中文（简体）&quot; } , { &quot;zh-Hant&quot; , &quot;繁體中文（繁體）&quot; } ]","ref":"readme.html#examples","title":"Cldr Locale Display - Examples","type":"extras"},{"doc":"","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"This is the changelog for Cldr Locale Display v1.2.0 released on October 28th, 2021. For older changelogs please consult the release tag on GitHub Enhancements Updated to ex_cldr 2.24 which implements CLDR 40 data.","ref":"changelog.html#cldr-locale-display-v1-2-0","title":"Changelog - Cldr Locale Display v1.2.0","type":"extras"},{"doc":"This is the changelog for Cldr Locale Display v1.2.0-rc.0 released on October 20th, 2021. For older changelogs please consult the release tag on GitHub Enhancements Updated to ex_cldr 2.24 which implements CLDR 40 data.","ref":"changelog.html#cldr-locale-display-v1-2-0-rc-0","title":"Changelog - Cldr Locale Display v1.2.0-rc.0","type":"extras"},{"doc":"This is the changelog for Cldr Locale Display v1.1.2 released on July 3rd, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fix bug where not all locales have display names for the key t or the type h0 Fix bug where the locale into which we are localising is valid but not configured","ref":"changelog.html#cldr-locale-display-v1-1-2","title":"Changelog - Cldr Locale Display v1.1.2","type":"extras"},{"doc":"This is the changelog for Cldr Locale Display v1.1.1 released on July 3rd, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Actual fixes for the issue when the compound name includes the script (like zh-Hant).","ref":"changelog.html#cldr-locale-display-v1-1-1","title":"Changelog - Cldr Locale Display v1.1.1","type":"extras"},{"doc":"This is the changelog for Cldr Locale Display v1.1.0 released on July 3rd, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Correct an issue when the compound name includes the script (like zh-Hant). Enhancements Add display_names/{1,2} to backend modules.","ref":"changelog.html#cldr-locale-display-v1-1-0","title":"Changelog - Cldr Locale Display v1.1.0","type":"extras"},{"doc":"This is the changelog for Cldr Locale Display v1.0.0 released on July 1st, 2021. For older changelogs please consult the release tag on GitHub Enhancements This is the first release of ex_cldr_locale_display which implements the CLDR locale display name algorithm .","ref":"changelog.html#cldr-locale-display-v1-0-0","title":"Changelog - Cldr Locale Display v1.0.0","type":"extras"},{"doc":"","ref":"license.html","title":"LICENSE","type":"extras"},{"doc":"Copyright 2018 Kip Cole Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http :// www . apache . org / licenses / LICENSE - 2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"license.html#license","title":"LICENSE - License","type":"extras"}]